# Meter Frontend Takehome Exercise

This project is a loose sketch of our admin site. It is a single-page app using
React written in TypeScript. It talks to a mock API served
by [json-server](https://github.com/typicode/json-server). The project
uses [Chakra UI](https://chakra-ui.com/) as a component library
and [react-query](https://react-query.tanstack.com/) for data fetching.

## Getting Started

You will need Node (any version >= 14) and Yarn (available
via `npm install -g yarn`) installed on your system to get started.

1. Install Node dependencies by running:

    ```
    yarn
    ```

2. Start the development server and API by running:

    ```
    yarn start
    ```

   This command will start the dev server on port `:3000` and the API server on
   port `:4000`.

3. Open the app by visiting http://localhost:3000. At this point, you should see
   a simple UI with a list of networks. Feel free to click around!

> Note: The dev server will proxy requests starting with `/api` to the API
> server, stripping the `/api` prefix. Feel free to open
> http://localhost:4000 to explore the API endpoints.

## Domain Objects

For the purpose of this exercise, the "API" is served up from a static JSON file
located in the `api/` directory.

There are three main types of objects:

- **Networks** represent the Meter-managed networks at a customer's
  location. They're the top-level entity that this project deals with.

- **Access points** are Meter hardware devices in the office. They're the
  hardware you see on the ceiling of any office that broadcasts a WiFi signal.

- **Clients** are devices connected to the network either directly via Ethernet
  or wirelessly through an access point.

## Your Tasks

There are two tasks as part of this problem:

1. Client List and Detail Views
2. Renaming a Network

We would like for you to **spend no more than 3-4 hours on this project**. This
is based on an honor system, but our goal is to respect your time. **If you
reach this time limit and haven't completed every piece, that's ok!** Please jot
down your thoughts on how you might approach the remaining work in your
RESPONSE.md (see below).

### Clients List and Detail Views

Our users would like to see a list of all clients associated with a network. If
you navigate to view a network's details, you will see that the "Clients" box
has a big "To-do!" banner on it. This is for you to implement.

The API endpoint `/api/network/:networkId/clients` will return a list of
the clients associated with a network. The endpoint `/api/clients/:clientId`
will return details for a single client.

We would like for you to implement a view that lists clients on a network. We
would also like for you to implement a more detailed view of client information.
Feel free to borrow as much as you would like from the access points implementation.

#### Client list:

- Name
  - This is available at `lease.name` and represents the name of the client on
    the network.
- IP address
  - This is the IP address of the client on the local network.
- MAC address
  - This is a unique identifier for the client's network interface.
- Connection type (wired or wireless)

#### Client detail:

- Name
- IP address
- MAC address
- Connection type
- For wireless connections:
  - Tx / Rx rate, formatted like "120 Mbps / 100 Mbps"
    - Tx and Rx rates describe the rate that the client can transmit and
      receive data from the access point, respectively.
  - Channel
    - Channel describes the frequency band on which data is transmitted
      between clients and an access point. It's similar to the frequency of a
      radio station.
  - Signal strength (formatted like "-60 dBm")
    - Signal strength describes the power of the wireless signal received by
      the client. It is measured in decibels (dB) relative to one milliwatt
      (mW).
  - Noise (formatted like "-94 dBm")
    - Noise describes the amount of background interference in the nearby
      environment. It is also measured in decibels relative to one mW.

#### Tips and pointers

If you haven't found the file yet, `src/api.ts` contains some code for making
API requests. You will likely need to extend this code as part of your solution
for this task.

`src/types/api.d.ts` contains some type definitions for the API, including the
`ClientData` type which might help during this task.

### Renaming a Network

You may have noticed that most networks have bogus names. These are randomly
generated. Our users would like to be able to rename networks.

You can rename a network using a PATCH request to
`/api/network/:networkId` with a request body like:

```json
{
  "name": "New name"
}
```

We would like for you to implement a UI that allows our users to rename an
individual network and persists the name through the API. Your implementation
should validate that the user has not supplied an empty name. Your design
doesn't have to look pretty, but we expect it to be functional.

> Note: The API persists changes to disk. If you restart the server, changes you
made before will persist. If you need to reset to a fresh state, you may remove
the `api/data.json` file and run `yarn start` again.

#### Tips and pointers

You might refer to react-query's [docs on
mutations](https://react-query.tanstack.com/guides/mutations) while you
implement this. Consider how you might handle stale data.

You might also consider using Chakra's
[Editable](https://chakra-ui.com/docs/components/form/editable) component for
the UI, though you don't have to!

## Submit your responses

When you finish, please write up a brief summary of the work you did in a doc
named `RESPONSE.md`. We are particularly interested in any choices you made and
what you might have chosen to do differently with more time. If you didn't
complete every task, feel free to jot down your thoughts on those as well. If
you feel that there is anything else to note about your submission, feel free to
mention it here too.

Finally, run `yarn pack` to create an archive of the project and send it back to
us.
