import { ChakraProvider } from '@chakra-ui/react';
import { NetworkDetailPage } from './pages/NetworkDetailPage';
import { BrowserRouter, Route, Routes } from 'react-router-dom';
import { NetworkListPage } from './pages/NetworkListPage';
import {
  AccessPointDetailPanel,
  NetworkAccessPointsPage,
} from './pages/NetworkAccessPointsPage';
import {
  ClientDetailPanel,
  NetworkClientsPage,
} from './pages/NetworkClientsPage';
import { QueryClient, QueryClientProvider } from 'react-query';
import { NotFoundPage } from './pages/NotFoundPage';
import { AppLayout } from './layouts/AppLayout';

const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      suspense: true,
    },
  },
});

export const App: React.FC = () => (
  <ChakraProvider>
    <QueryClientProvider client={queryClient}>
      <BrowserRouter>
        <Routes>
          <Route element={<AppLayout />}>
            <Route path="/" element={<NetworkListPage />} />
            <Route path="network/:networkId">
              <Route index element={<NetworkDetailPage />} />
              <Route path="aps" element={<NetworkAccessPointsPage />}>
                <Route path={':apId'} element={<AccessPointDetailPanel />} />
              </Route>
              <Route path="clients" element={<NetworkClientsPage />}>
                <Route path={':clientId'} element={<ClientDetailPanel />} />
              </Route>
            </Route>
            <Route path="*" element={<NotFoundPage />} />
          </Route>
        </Routes>
      </BrowserRouter>
    </QueryClientProvider>
  </ChakraProvider>
);
