import axios from 'axios';
import {
  AccessPointAndRadioData,
  ClientData,
  NetworkData,
  StatsData,
} from './types/api';

const delay = (ms: number) => new Promise((resolve) => setTimeout(resolve, ms));

const instance = axios.create({
  baseURL: '/api/',
});

// Simulate a slow network with 200-400ms latency
instance.interceptors.request.use(async (config) => {
  await delay((1 + Math.random()) * 200);
  return config;
});

export const api = {
  network: {
    list: () =>
      instance.get<NetworkData[]>('/networks').then((res) => res.data),
    detail: (id: string) =>
      instance.get<NetworkData>(`/networks/${id}`).then((res) => res.data),
    stats: (id: string) =>
      instance
        .get<StatsData[]>(`/networks/${id}/stats`)
        .then((res) => res.data[0] ?? null),
    accessPoints: (id: string) =>
      instance
        .get<AccessPointAndRadioData[]>(`/networks/${id}/access_points`)
        .then((res) => res.data),
    clients: (id: string) =>
      instance
        .get<ClientData[]>(`/networks/${id}/clients`)
        .then((res) => res.data),
    rename: (id: string, name: string) =>
      instance
        .patch<NetworkData>(`/networks/${id}`, { name })
        .then((res) => res.data),
  },
  accessPoint: {
    detail: (id: string) =>
      instance
        .get<AccessPointAndRadioData[]>(`/access_points/${id}`)
        .then((res) => res.data[0] ?? null),
  },
  client: {
    detail: (id: string) =>
      instance.get<ClientData>(`/clients/${id}`).then((res) => res.data),
  },
};
