const formatBps = (value: number, scale: number, decimals: number = 2) => {
  if (value === 0) return '0 bits/s';
  if (value === -1 || Number.isNaN(value)) {
    return 'n/a';
  }

  const k = 1024;
  const dm = decimals < 0 ? 0 : decimals;
  const sizes = ['bps', 'Kbps', 'Mbps', 'Gbps', 'Tbps'];

  const bps = value * scale;
  const i = Math.floor(Math.log(bps) / Math.log(k));

  return `${parseFloat((bps / k ** i).toFixed(dm))} ${sizes[i]}`;
};

export const formatBytesAsBps = (bytes: number, decimals: number = 2) =>
  formatBps(bytes, 8, decimals);
