import { NetworkData } from '../types/api';
import { useMemo } from 'react';
import { Column } from 'react-table';
import {
  Breadcrumb,
  BreadcrumbItem,
  BreadcrumbLink,
  Code,
} from '@chakra-ui/react';
import { DataTable } from '../components/DataTable';
import { api } from '../api';
import { PageLayout } from '../layouts/PageLayout';
import { Link } from 'react-router-dom';
import { OnlineOfflineBadge } from '../components/OnlineOfflineBadge';
import { useQuery } from 'react-query';

export const NetworkListPage: React.FC = () => {
  const { data: networks } = useQuery('networks', api.network.list);

  const columns = useMemo<Column<NetworkData>[]>(
    () => [
      { Header: 'Name', accessor: 'name' },
      { Header: 'Customer', accessor: 'customer_name' },
      {
        Header: 'Hostname',
        accessor: 'hostname',
        Cell: (props) => <Code>{props.cell.value}</Code>,
      },
      { Header: 'Address', accessor: 'address' },
      {
        Header: 'Status',
        accessor: 'status',
        Cell: (props) => <OnlineOfflineBadge value={props.cell.value} />,
      },
    ],
    [],
  );

  return (
    <PageLayout
      title="Networks"
      breadcrumbs={
        <Breadcrumb px={6}>
          <BreadcrumbItem>
            <BreadcrumbLink as={Link} to="/" isCurrentPage>
              Networks
            </BreadcrumbLink>
          </BreadcrumbItem>
        </Breadcrumb>
      }
      content={
        <DataTable
          columns={columns}
          data={networks ?? []}
          rowLinkProps={(row) => ({ to: `/network/${row.id}` })}
        />
      }
    />
  );
};
