export interface NetworkData {
  id: string;
  created_at: string;
  name: string;
  customer_name: string;
  hostname: string;
  address: string;
  square_feet: number;
  updated_at: string;
  status: 'offline' | 'online';
}

export interface StatsData {
  network_id: string;
  download_bytes: number;
  upload_bytes: number;
  created_at: string;
  bandwidth_updated_at: string;
  last_rebooted_at: string;
}

export interface AccessPointData {
  id: string;
  version: string;
  location: string;
  created_at: string;
  updated_at: string;
  network_id: string;
  name: string;
  connected_clients: number;
  status: 'online' | 'offline';
}

export interface RadioData {
  band: string;
  channel: number;
  channel_width: number;
  power: number;
  disabled: boolean;
  created_at: string;
  updated_at: string;
}

export interface AccessPointAndRadioData {
  access_point: AccessPointData;
  radios: RadioData[];
}

export interface ClientLeaseData {
  network_id: string;
  ip: string;
  name: string;
  expiry: string;
  mac: string;
}

export interface WiredClientData {
  id: string;
  connection_type: 'wired';
  lease: ClientLeaseData;
  connected: boolean;
  last_seen: string;
}

export interface WirelessConnectionData {
  access_point_id: string;
  tx_rate_bytes: number;
  rx_rate_bytes: number;
  signal_dbm: number;
  noise_dbm: number;
  channel: number;
}

export interface WirelessClientData {
  id: string;
  connection_type: 'wireless';
  lease: ClientLeaseData;
  wireless_info: WirelessConnectionData;
  connected: boolean;
  last_seen: string;
}

export type ClientData = WirelessClientData | WiredClientData;
